==> openturns_1.0.orig.tar.bz2: openturns-1.0/lib/test/t_LogNormal_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_LogNormal_std.cxx
 *  @brief The test file of class LogNormal for standard methods
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012) $
 *  Id:      $Id: t_LogNormal_std.cxx 2392 2012-02-17 18:35:43Z schueller $
 */
#include <iostream>
#include <sstream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "LogNormal.hxx"
#include "NumericalPoint.hxx"
#include "NumericalSample.hxx"

using namespace OT;
using namespace OT::Test;


class TestObject : public LogNormal
{
public:
  explicit TestObject() : LogNormal(-1.0, 1.5, -0.5) {}
  explicit TestObject(const String & name) : LogNormal(-1.0, 1.5, -0.5) {setName(name);}
  virtual ~TestObject() {}
};


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try {
    // Test basic functionnalities
    checkClassWithClassName<TestObject>();

    // Test some extra functionnalities
    checkNameFeature<TestObject>();

    // Instanciate one distribution object
    LogNormal distribution(-1.0, 1.5, -0.5);
    fullprint << "Distribution " << distribution << std::endl;
    std::cout << "Distribution " << distribution << std::endl;

    // Is this distribution elliptical ?
    fullprint << "Elliptical = " << (distribution.isElliptical() ? "true" : "false") << std::endl;

    // Is this distribution continuous ?
    fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;

    // Test for realization of distribution
    NumericalPoint oneRealization = distribution.getRealization();
    fullprint << "oneRealization=" << oneRealization << std::endl;

    // Test for sampling
    UnsignedLong size = 10000;
    NumericalSample oneSample = distribution.getNumericalSample( size );
    fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
    fullprint << "mean=" << oneSample.computeMean() << std::endl;
    fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;

    // Define a point
    NumericalPoint point( distribution.getDimension(), 1.0 );
    fullprint << "Point= " << point << std::endl;

    // Show PDF and CDF of point
    NumericalScalar eps(1e-5);
    NumericalPoint DDF = distribution.computeDDF( point );
    fullprint << "ddf     =" << DDF << std::endl;
    fullprint << "ddf (FD)=" << NumericalPoint(1, (distribution.computePDF( point + NumericalPoint(1, eps) ) - distribution.computePDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps)) << std::endl;
    NumericalScalar PDF = distribution.computePDF( point );
    fullprint << "pdf     =" << PDF << std::endl;
    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
    NumericalScalar CDF = distribution.computeCDF( point );
    fullprint << "cdf=" << CDF << std::endl;
    NumericalComplex CF = distribution.computeCharacteristicFunction( point[0] );
    fullprint << "characteristic function=" << CF << std::endl;
    NumericalPoint PDFgr = distribution.computePDFGradient( point );
    fullprint << "pdf gradient     =" << PDFgr << std::endl;
    NumericalPoint PDFgrFD(3);
    PDFgrFD[0] = (LogNormal(distribution.getMuLog() + eps, distribution.getSigmaLog(), distribution.getGamma()).computePDF(point) -
                  LogNormal(distribution.getMuLog() - eps, distribution.getSigmaLog(), distribution.getGamma()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[1] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog() + eps, distribution.getGamma()).computePDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog() - eps, distribution.getGamma()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[2] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() + eps).computePDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() - eps).computePDF(point)) / (2.0 * eps);
    fullprint << "pdf gradient (FD)=" << PDFgrFD << std::endl;
    NumericalPoint CDFgr = distribution.computeCDFGradient( point );
    fullprint << "cdf gradient     =" << CDFgr << std::endl;
    NumericalPoint CDFgrFD(3);
    CDFgrFD[0] = (LogNormal(distribution.getMuLog() + eps, distribution.getSigmaLog(), distribution.getGamma()).computeCDF(point) -
                  LogNormal(distribution.getMuLog() - eps, distribution.getSigmaLog(), distribution.getGamma()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[1] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog() + eps, distribution.getGamma()).computeCDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog() - eps, distribution.getGamma()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[2] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() + eps).computeCDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() - eps).computeCDF(point)) / (2.0 * eps);
    fullprint << "cdf gradient (FD)=" << CDFgrFD << std::endl;
    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
    fullprint << "quantile=" << quantile << std::endl;
    fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
    NumericalPoint mean = distribution.getMean();
    fullprint << "mean=" << mean << std::endl;
    NumericalPoint standardDeviation = distribution.getStandardDeviation();
    fullprint << "standard deviation=" << standardDeviation << std::endl;
    NumericalPoint skewness = distribution.getSkewness();
    fullprint << "skewness=" << skewness << std::endl;
    NumericalPoint kurtosis = distribution.getKurtosis();
    fullprint << "kurtosis=" << kurtosis << std::endl;
    CovarianceMatrix covariance = distribution.getCovariance();
    fullprint << "covariance=" << covariance << std::endl;
    LogNormal::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
    fullprint << "parameters=" << parameters << std::endl;

    // Specific to this distribution
    NumericalScalar mu(distribution.getMu());
    fullprint << "mu=" << mu << std::endl;
    NumericalScalar sigma(distribution.getSigma());
    fullprint << "sigma=" << sigma << std::endl;
    LogNormal newDistribution(mu, sigma, distribution.getGamma(), LogNormal::MUSIGMA);
    fullprint << "muLog from (mu, sigma)=" << newDistribution.getMuLog() << std::endl;
    fullprint << "sigmaLog from (mu, sigma)=" << newDistribution.getSigmaLog() << std::endl;
    NumericalScalar sigmaOverMu(distribution.getSigmaOverMu());
    fullprint << "sigmaOverMu=" << sigmaOverMu << std::endl;
    newDistribution = LogNormal(mu, sigmaOverMu, distribution.getGamma(), LogNormal::MU_SIGMAOVERMU);
    fullprint << "muLog from (mu, sigmaOverMu)=" << newDistribution.getMuLog() << std::endl;
    fullprint << "sigmaLog from (mu, sigmaOverMu)=" << newDistribution.getSigmaLog() << std::endl;
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.2.orig.tar.bz2: openturns-1.2/lib/test/t_LogNormal_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_LogNormal_std.cxx
 *  @brief The test file of class LogNormal for standard methods
 *
 *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-07-16 15:59:45 +0200 (Mon, 16 Jul 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

class TestObject : public LogNormal
{
public:
  explicit TestObject() : LogNormal(-1.0, 1.5, -0.5) {}
  explicit TestObject(const String & name) : LogNormal(-1.0, 1.5, -0.5)
  {
    setName(name);
  }
  virtual ~TestObject() {}
};


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    // Test basic functionnalities
    checkClassWithClassName<TestObject>();

    // Test some extra functionnalities
    checkNameFeature<TestObject>();

    // Instanciate one distribution object
    LogNormal distribution(-1.0, 1.5, -0.5);
    fullprint << "Distribution " << distribution << std::endl;
    std::cout << "Distribution " << distribution << std::endl;

    // Is this distribution elliptical ?
    fullprint << "Elliptical = " << (distribution.isElliptical() ? "true" : "false") << std::endl;

    // Is this distribution continuous ?
    fullprint << "Continuous = " << (distribution.isContinuous() ? "true" : "false") << std::endl;

    // Test for realization of distribution
    NumericalPoint oneRealization = distribution.getRealization();
    fullprint << "oneRealization=" << oneRealization << std::endl;

    // Test for sampling
    UnsignedLong size = 10000;
    NumericalSample oneSample = distribution.getSample( size );
    fullprint << "oneSample first=" << oneSample[0] << " last=" << oneSample[size - 1] << std::endl;
    fullprint << "mean=" << oneSample.computeMean() << std::endl;
    fullprint << "covariance=" << oneSample.computeCovariance() << std::endl;
    size = 100;
    for (UnsignedLong i = 0; i < 5; ++i)
    {
      RandomGenerator::SetSeed(1);
      fullprint << "Kolmogorov test for the generator, sample size=" << size << " is " << (FittingTest::Kolmogorov(distribution.getSample(size), distribution).getBinaryQualityMeasure() ? "accepted" : "rejected") << std::endl;
      size *= 10;
    }

    // Define a point
    NumericalPoint point( distribution.getDimension(), 1.0 );
    fullprint << "Point= " << point << std::endl;

    // Show PDF and CDF of point
    NumericalScalar eps(1e-5);
    NumericalPoint DDF = distribution.computeDDF( point );
    fullprint << "ddf     =" << DDF << std::endl;
    fullprint << "ddf (FD)=" << distribution.ContinuousDistribution::computeDDF(point) << std::endl;
    NumericalScalar LPDF = distribution.computeLogPDF( point );
    fullprint << "log pdf=" << LPDF << std::endl;
    NumericalScalar PDF = distribution.computePDF( point );
    fullprint << "pdf     =" << PDF << std::endl;
    fullprint << "pdf (FD)=" << (distribution.computeCDF( point + NumericalPoint(1, eps) ) - distribution.computeCDF( point  + NumericalPoint(1, -eps) )) / (2.0 * eps) << std::endl;
    NumericalScalar CDF = distribution.computeCDF( point );
    fullprint << "cdf=" << CDF << std::endl;
    NumericalScalar CCDF = distribution.computeComplementaryCDF( point );
    fullprint << "ccdf=" << CCDF << std::endl;
    NumericalComplex CF = distribution.computeCharacteristicFunction( point[0] );
    fullprint << "characteristic function=" << CF << std::endl;
    NumericalComplex LCF = distribution.computeLogCharacteristicFunction( point[0] );
    fullprint << "log characteristic function=" << LCF << std::endl;
    NumericalPoint PDFgr = distribution.computePDFGradient( point );
    fullprint << "pdf gradient     =" << PDFgr << std::endl;
    NumericalPoint PDFgrFD(3);
    PDFgrFD[0] = (LogNormal(distribution.getMuLog() + eps, distribution.getSigmaLog(), distribution.getGamma()).computePDF(point) -
                  LogNormal(distribution.getMuLog() - eps, distribution.getSigmaLog(), distribution.getGamma()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[1] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog() + eps, distribution.getGamma()).computePDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog() - eps, distribution.getGamma()).computePDF(point)) / (2.0 * eps);
    PDFgrFD[2] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() + eps).computePDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() - eps).computePDF(point)) / (2.0 * eps);
    fullprint << "pdf gradient (FD)=" << PDFgrFD << std::endl;
    NumericalPoint CDFgr = distribution.computeCDFGradient( point );
    fullprint << "cdf gradient     =" << CDFgr << std::endl;
    NumericalPoint CDFgrFD(3);
    CDFgrFD[0] = (LogNormal(distribution.getMuLog() + eps, distribution.getSigmaLog(), distribution.getGamma()).computeCDF(point) -
                  LogNormal(distribution.getMuLog() - eps, distribution.getSigmaLog(), distribution.getGamma()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[1] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog() + eps, distribution.getGamma()).computeCDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog() - eps, distribution.getGamma()).computeCDF(point)) / (2.0 * eps);
    CDFgrFD[2] = (LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() + eps).computeCDF(point) -
                  LogNormal(distribution.getMuLog(), distribution.getSigmaLog(), distribution.getGamma() - eps).computeCDF(point)) / (2.0 * eps);
    fullprint << "cdf gradient (FD)=" << CDFgrFD << std::endl;
    NumericalPoint quantile = distribution.computeQuantile( 0.95 );
    fullprint << "quantile=" << quantile << std::endl;
    fullprint << "cdf(quantile)=" << distribution.computeCDF(quantile) << std::endl;
    NumericalPoint mean = distribution.getMean();
    fullprint << "mean=" << mean << std::endl;
    NumericalPoint standardDeviation = distribution.getStandardDeviation();
    fullprint << "standard deviation=" << standardDeviation << std::endl;
    NumericalPoint skewness = distribution.getSkewness();
    fullprint << "skewness=" << skewness << std::endl;
    NumericalPoint kurtosis = distribution.getKurtosis();
    fullprint << "kurtosis=" << kurtosis << std::endl;
    CovarianceMatrix covariance = distribution.getCovariance();
    fullprint << "covariance=" << covariance << std::endl;
    LogNormal::NumericalPointWithDescriptionCollection parameters = distribution.getParametersCollection();
    fullprint << "parameters=" << parameters << std::endl;
    fullprint << "parameters=" << parameters << std::endl;
    for (UnsignedLong i = 0; i < 6; ++i) fullprint << "standard moment n=" << i << ", value=" << distribution.getStandardMoment(i) << std::endl;
    fullprint << "Standard representative=" << distribution.getStandardRepresentative()->__str__() << std::endl;

    // Specific to this distribution
    NumericalScalar mu(distribution.getMu());
    fullprint << "mu=" << mu << std::endl;
    NumericalScalar sigma(distribution.getSigma());
    fullprint << "sigma=" << sigma << std::endl;
    LogNormal newDistribution(mu, sigma, distribution.getGamma(), LogNormal::MUSIGMA);
    fullprint << "muLog from (mu, sigma)=" << newDistribution.getMuLog() << std::endl;
    fullprint << "sigmaLog from (mu, sigma)=" << newDistribution.getSigmaLog() << std::endl;
    NumericalScalar sigmaOverMu(distribution.getSigmaOverMu());
    fullprint << "sigmaOverMu=" << sigmaOverMu << std::endl;
    newDistribution = LogNormal(mu, sigmaOverMu, distribution.getGamma(), LogNormal::MU_SIGMAOVERMU);
    fullprint << "muLog from (mu, sigmaOverMu)=" << newDistribution.getMuLog() << std::endl;
    fullprint << "sigmaLog from (mu, sigmaOverMu)=" << newDistribution.getSigmaLog() << std::endl;
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
